summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrFindReplace.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kpresenter/KPrFindReplace.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpresenter/KPrFindReplace.h')
-rw-r--r--kpresenter/KPrFindReplace.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpresenter/KPrFindReplace.h b/kpresenter/KPrFindReplace.h
index 54ee6861..e1495523 100644
--- a/kpresenter/KPrFindReplace.h
+++ b/kpresenter/KPrFindReplace.h
@@ -45,12 +45,12 @@ class KPrFindReplace : public KoFindReplace
TQ_OBJECT
public:
/**
* The tqparent widget can't be the canvas, otherwise the 'find next' dialog
* scrolls up/down when using the scrollbars (hehe, cool effect).
*/
- KPrFindReplace( TQWidget* tqparent, KPrCanvas * canvas, KoSearchDia * dialog,
+ KPrFindReplace( TQWidget* parent, KPrCanvas * canvas, KoSearchDia * dialog,
const TQValueList<KoTextObject *> & lstObjects, KPrTextView *textView );
- KPrFindReplace( TQWidget* tqparent, KPrCanvas * canvas, KoReplaceDia * dialog,
+ KPrFindReplace( TQWidget* parent, KPrCanvas * canvas, KoReplaceDia * dialog,
const TQValueList<KoTextObject *> & lstObjects, KPrTextView *textView );
~KPrFindReplace();
@@ -45,12 +45,12 @@ class KPrFindReplace : public KoFindReplace
public:
/**
- * The tqparent widget can't be the canvas, otherwise the 'find next' dialog
+ * The parent widget can't be the canvas, otherwise the 'find next' dialog
* scrolls up/down when using the scrollbars (hehe, cool effect).
*/